function plugindef()

   -- This function and the 'finaleplugin' namespace

   -- are both reserved for the plug-in definition.

   finaleplugin.RequireScore = true

   finaleplugin.MinJWLuaVersion = "0.11"

   finaleplugin.Author = "Jari Williamsson"

   finaleplugin.Version = "0.01"

   finaleplugin.Date = "November 27, 2013"

   finaleplugin.CategoryTags = "Text"

   finaleplugin.ParameterTypes = [[

NumberedList

Number

String

Number

NumberedList

]]

   finaleplugin.ParameterLists = [[

Title, Subtitle, Composer, Arranger, Lyricist, Copyright, Description, Score/Part Name, Page, Date, File Date, Time, Performance Time, Filename, Copyright Symbol

nil

nil

nil

Plain, Italic, Bold, Italic+Bold, Absolute+Plain, Absolute+Italic, Absolute+Bold, Absolute+Italic+Bold

]]

   finaleplugin.ParameterInitValues = [[

1

1

Times New Roman

12

1

]]

   finaleplugin.ParameterDescriptions = [[

Text insert text to change

Text start page

Font name

Font size

Font style

]]

   return "Page Text Font", "Page Text Font", "Changes the page text fonts based on the parameters."

end















--[[This script is based on parameters.

    Parameter 1: Script-defined index to the text insert that should be changed

    Parameter 2: Start page number with the text insert that should be changed

    Parameter 3: Font Name string

    Parameter 4: Font size

    Parameter 5: Script font-style index

]] 



-- Table with the starts of text inserts.

-- The index values are included only to reduce the risk of errors.

local textinsertstartstable =

{    

    [1] = "^title(",

    [2] = "^subtitle(",    

    [3] = "^composer(",

    [4] = "^arranger(",

    [5] = "^lyricist(",

    [6] = "^copyright(",

    [7] = "^description(",

    [8] = "^partname(",

    [9] = "^page(",    

    [10] = "^date(",

    [11] = "^fdate(",

    [12] = "^time(",

    [13] = "^perftime(",

    [14] = "^filename(",    

    [15] = "^cprsym("    

}



local fontstyletable = 

{

    [1] = function (style) style:SetPlain() end,

    [2] = function (style) style:SetPlain(); style.Italic = true end,

    [3] = function (style) style:SetPlain(); style.Bold = true end,

    [4] = function (style) style:SetPlain(); style.Bold = true; style.Italic = true end,

    [5] = function (style) style:SetPlain(); style.Absolute = true end,

    [6] = function (style) style:SetPlain(); style.Italic = true; style.Absolute = true end,

    [7] = function (style) style:SetPlain(); style.Bold = true; style.Absolute = true end,

    [8] = function (style) style:SetPlain(); style.Bold = true; style.Italic = true; style.Absolute = true end

}







-- Get the parameters. Exit script on any kind of possible error. 

local parameters = {...}

if not parameters then return end

local textinsertidx = parameters[1]

if not textinsertidx then return end

if not textinsertstartstable[textinsertidx] then return end



local startpage = parameters[2]

if not startpage then return end



local fontname = parameters[3]

if not fontname then return end

if fontname == "" then return end



local fontsize = parameters[4]

if not fontsize then return end

if fontsize < 4 then return end



local fontstyleidx = parameters[5]

if not fontstyleidx then return end

if not fontstyletable[fontstyleidx] then return end



local fontinfo = finale.FCFontInfo()

fontinfo.Name = fontname

fontinfo.Size = fontsize

fontstyletable[fontstyleidx](fontinfo)



function MapToTextInsert(str)

    local enigmastrings = str:CreateEnigmaStrings(false)

    for enigmastr in each(enigmastrings) do

        if enigmastr:StartsWith(textinsertstartstable[textinsertidx]) then

            local fontstring = fontinfo:CreateEnigmaString(nil)

            str:Insert(fontstring:GetLuaString(), 0)

            return true

        end

    end

    return false

end



local pagetexts = finale.FCPageTexts()

pagetexts:LoadAll()



for pagetext in each(pagetexts) do

    if pagetext.FirstPage == startpage then

        local str = pagetext:CreateTextString()

        str:TrimEnigmaFontTags()

        if MapToTextInsert(str) then

            pagetext:SaveTextString(str)

        end

    end

end
