function plugindef()

   -- This function and the 'finaleplugin' namespace

   -- are both reserved for the plug-in definition.

   finaleplugin.RequireScore = true

   finaleplugin.MinJWLuaVersion = "0.11"

   finaleplugin.Author = "Jari Williamsson"

   finaleplugin.Version = "0.01"

   finaleplugin.Date = "November 29, 2013"

   finaleplugin.CategoryTags = "Text"

   finaleplugin.ParameterTypes = [[

NumberedList

Number

Number

Number

]]

   finaleplugin.ParameterLists = [[

Title, Subtitle, Composer, Arranger, Lyricist, Copyright, Description, Score/Part Name, Page, Date, File Date, Time, Performance Time, Filename, Copyright Symbol

nil

nil

nil

]]

   finaleplugin.ParameterInitValues = [[

1

1

nil

nil

]]

   finaleplugin.ParameterDescriptions = [[

Text insert text to change

Text start page

Horizontal Position

Vertical Position

]]

   return "Page Text Position", "Page Text Position", "Changes the page text position based on the parameters."

end





--[[This script is based on parameters.

    Parameter 1: Script-defined index to the text insert that should be changed

    Parameter 2: Start page number with the text insert that should be changed

    Parameter 3: Horizontal Position

    Parameter 4: Vertical position

]] 



-- Table with the starts of text inserts.

-- The index values are included only to reduce the risk of errors.

local textinsertstartstable =

{    

    [1] = "^title(",

    [2] = "^subtitle(",    

    [3] = "^composer(",

    [4] = "^arranger(",

    [5] = "^lyricist(",

    [6] = "^copyright(",

    [7] = "^description(",

    [8] = "^partname(",

    [9] = "^page(",    

    [10] = "^date(",

    [11] = "^fdate(",

    [12] = "^time(",

    [13] = "^perftime(",

    [14] = "^filename(",    

    [15] = "^cprsym("    

}





-- Get the parameters. Exit script on any kind of possible error. 

local parameters = {...}

if not parameters then return end

local textinsertidx = parameters[1]

if not textinsertidx then return end

if not textinsertstartstable[textinsertidx] then return end



local startpage = parameters[2]

if not startpage then return end



local horizpos = parameters[3]

if not horizpos then return end



local vertpos = parameters[4]

if not vertpos then return end



-- Returns true if the raw string contains the correct text insert

function HasTextInsert(str)

    local enigmastrings = str:CreateEnigmaStrings(false)

    for enigmastr in each(enigmastrings) do

        if enigmastr:StartsWith(textinsertstartstable[textinsertidx]) then return true  end

    end

    return false

end



-- Load all text blocks

local pagetexts = finale.FCPageTexts()

pagetexts:LoadAll()



for pagetext in each(pagetexts) do

    if pagetext.FirstPage == startpage then

        local str = pagetext:CreateTextString()

        str:TrimEnigmaFontTags()

        if HasTextInsert(str) then

            pagetext.HorizontalPos = horizpos

            pagetext.VerticalPos = vertpos

            pagetext:Save()

        end

    end

end
