function plugindef()

   -- This function and the 'finaleplugin' namespace

   -- are both reserved for the plug-in definition.

   finaleplugin.RequireScore = true

   finaleplugin.MinJWLuaVersion = "0.12"

   finaleplugin.Author = "Jari Williamsson"

   finaleplugin.Version = "0.01"

   finaleplugin.Date = "November 29, 2013"

   finaleplugin.CategoryTags = "Staff"

   finaleplugin.ParameterTypes = [[

String

Number

NumberedList

]]

   finaleplugin.ParameterLists = [[

nil

nil

Plain, Italic, Bold, Italic+Bold, Absolute+Plain, Absolute+Italic, Absolute+Bold, Absolute+Italic+Bold

]]

   finaleplugin.ParameterInitValues = [[

Times New Roman

12

1

]]

   finaleplugin.ParameterDescriptions = [[

Font Name

Font Size

Font Style

]]

   return "Staff Name Font", "Staff Name Font", "Changes the staff name fonts (both full and abbreviated) for all staves."

end









--[[This script is based on parameters.    

    Parameter 1: Font Name string

    Parameter 2: Font size

    Parameter 3: Script font-style index

]] 



local fontstyletable = 

{

    [1] = function (style) style:SetPlain() end,

    [2] = function (style) style:SetPlain(); style.Italic = true end,

    [3] = function (style) style:SetPlain(); style.Bold = true end,

    [4] = function (style) style:SetPlain(); style.Bold = true; style.Italic = true end,

    [5] = function (style) style:SetPlain(); style.Absolute = true end,

    [6] = function (style) style:SetPlain(); style.Italic = true; style.Absolute = true end,

    [7] = function (style) style:SetPlain(); style.Bold = true; style.Absolute = true end,

    [8] = function (style) style:SetPlain(); style.Bold = true; style.Italic = true; style.Absolute = true end

}



-- Get the parameters. Exit script on any kind of possible error. 

local parameters = {...}

if not parameters then return end



local fontname = parameters[1]

if not fontname then return end

if fontname == "" then return end



local fontsize = parameters[2]

if not fontsize then return end

if fontsize < 4 then return end



local fontstyleidx = parameters[3]

if not fontstyleidx then return end

if not fontstyletable[fontstyleidx] then return end



local fontinfo = finale.FCFontInfo()

fontinfo.Name = fontname

fontinfo.Size = fontsize

fontstyletable[fontstyleidx](fontinfo)



local allstaves = finale.FCStaves()

allstaves:LoadAll()



for staff in each(allstaves) do    

    local str = staff:CreateFullNameString()

    str:TrimEnigmaFontTags()    

    local fontstring = fontinfo:CreateEnigmaString(nil)

    str:Insert(fontstring:GetLuaString(), 0)

    staff:SaveFullNameString(str)    



    str = staff:CreateAbbreviatedNameString()

    str:TrimEnigmaFontTags()    

    fontstring = fontinfo:CreateEnigmaString(nil)

    str:Insert(fontstring:GetLuaString(), 0)

    staff:SaveAbbreviatedNameString(str)    

end
